ProductModel class

Constructors

ProductModel({required int id, required String title, required double price, required String description, required String category, required String image, required Rating rating})
ProductModel.fromJson(Map<String, dynamic> json)
factory

Properties

category String
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
image String
getter/setter pair
price double
getter/setter pair
rating Rating
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited