UserModel class

Constructors

UserModel({required Address address, required int id, required String email, required String username, required String password, required Name name, required String phone, required int v})
UserModel.fromJson(Map<String, dynamic> json)
factory

Properties

address Address
getter/setter pair
email String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
name Name
getter/setter pair
password String
getter/setter pair
phone String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
getter/setter pair
v int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited